# anndatavis
AnnData interactive visualization widget for Jupyter NB/lab

## Getting started
### Installation
pip install anndatavis

#### Dependencies
Scanpy, numpy, plotly

### Demo notebook
See examples/anndata_visualization_demo.ipynb   
For the demo make sure to install the leiden clustering package (pip install leidenalg)



